hstrat.hstrat.stratum\_retention\_predicates.StratumRetentionPredicateNominalResolution
=======================================================================================

.. currentmodule:: hstrat.hstrat.stratum_retention_predicates

.. autoclass:: StratumRetentionPredicateNominalResolution

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~StratumRetentionPredicateNominalResolution.CalcMrcaUncertaintyUpperBound
      ~StratumRetentionPredicateNominalResolution.CalcNumStrataRetainedExact
      ~StratumRetentionPredicateNominalResolution.CalcNumStrataRetainedUpperBound
      ~StratumRetentionPredicateNominalResolution.CalcRankAtColumnIndex
      ~StratumRetentionPredicateNominalResolution.__init__
   
   

   
   
   